@@ -16,6 +16,8 @@ def tbg(n=7,ti=0.12,lambi=3.0,lamb=3.0,is_sparse=True,
             is_multicell=True,mgenerator=mgenerator)
     return h
 
+twisted_bilayer_graphene = tbg
+
 
 def multilayer_graphene(l=[0],real=False,**kwargs):
   """Return the hamiltonian of multilayer graphene"""
@@ -51,21 +53,42 @@ def valence_TMDC(g=None,soc=0.0,**kwargs):
     if g is None:
         g = geometry.triangular_lattice()
     ft = specialhopping.phase_C3(g,phi=soc,**kwargs)
-    h = g.get_hamiltonian(fun=ft,is_multicell=True,has_spin=False)
+    h = g.get_hamiltonian(tij=ft,is_multicell=True,has_spin=False)
     h.turn_spinful(enforce_tr=True)
     return h # return the Hamiltonian
 
 
+def SOC_TMDC(g=None,soc=0.0,**kwargs):
+    """Return the Ising SOC for a triangular lattice"""
+    if g is None:
+        g = geometry.triangular_lattice()
+    ft0 = specialhopping.phase_C3(g,phi=.5,**kwargs)
+    ft = lambda r1,r2: 1j*(ft0(r1,r2).imag) # only imaginary part
+    h = g.get_hamiltonian(tij=ft,is_multicell=True,has_spin=False)
+    h.turn_spinful(enforce_tr=True)
+    return h # return the Hamiltonian
+
+
+
+
 def NbSe2(**kwargs):
-#    return TMDC_MX2(**kwargs,ts=[0.0263,0.099,-0.0014,-0.0112,-0.0146,0.0025])
-    return TMDC_MX2(**kwargs,ts=[0.026,0.1,-0.0014,-0.011,-0.015,0.003])
+#    return TMDC_MX2(**kwargs,ts=[0.0263,0.0991,-0.0014,-0.0112,-0.0146,0.0025])
+    return TMDC_MX2(**kwargs,
+            ts=[0.02126916,  0.08462639,  0.00504899, -0.00906057, -0.00572983])
 #    return TMDC_MX2(**kwargs,ts=[0.3,2.,0.6,0.2,0.])
 
 def TaS2(**kwargs):
-    return TMDC_MX2(**kwargs,ts=[0.0263,0.099,-0.0014,-0.0112,-0.0146,0.0025])
-    #return TMDC_MX2(**kwargs,ts=[0.2,2.,0.6,0.2,0.])
+    return TMDC_MX2(**kwargs,
+             ts=[ 0.05525963, 0.08784492, -0.00185766, -0.01204535 ,0.00220995])
 
-def TMDC_MX2(soc=0.0,cdw=0.0,g=None,ts=[1.0]):
+
+def TaS2_SOC(**kwargs):
+    return TMDC_MX2(**kwargs,soc=-0.5451483039554,
+             ts=[0.05901736,0.10243251,-0.00172311,-0.00993678,0.00459015])
+
+
+
+def TMDC_MX2(soc=0.0,cdw=0.0,g=None,ts=[1.0],normalize=True):
     """Return the Hamiltonian of NbSe2"""
     if g is None: 
         g = geometry.triangular_lattice()  # triangular lattice
@@ -73,7 +96,7 @@ def TMDC_MX2(soc=0.0,cdw=0.0,g=None,ts=[1.0]):
 #    ts = [1.0,0.3,0.6]
     ts = np.array(ts)
 #    t = ts[0]/np.max(ts) # 1NN 
-    ts = ts/np.max(ts) # normalize
+    if normalize: ts = ts/np.max(ts) # normalize
 #    fm = specialhopping.neighbor_hopping_matrix(g,ts) # function for hoppings
     h = g.get_hamiltonian(is_multicell=True,has_spin=False,ts=ts)
     ## Now add the SOC if necessary
@@ -81,7 +104,7 @@ def TMDC_MX2(soc=0.0,cdw=0.0,g=None,ts=[1.0]):
         h.turn_spinful() # turn spinful
         d = g.neighbor_distances()[1]
         d = 1.0
-        hsoc = valence_TMDC(g=h.geometry,soc=soc,d=d) # hamiltonian with SOC
+        hsoc = ts[0]*soc*SOC_TMDC(g=h.geometry,d=d) # hamiltonian with SOC
         h = h + hsoc # add the two Hamiltonians
     if cdw!=0.0: # add the CDW
         g0 = geometry.triangular_lattice()  # triangular lattice
